@@ -1,9 +1,7 @@
-import numpy as np
-
 from signum.core.base_container import SignalContainer, SCA
 
 
-class FreqDomainSignal(SignalContainer):
+class BaseFreqDomainSignal(SignalContainer):
     ATTRIBUTES = SignalContainer.ATTRIBUTES + [SCA('_f_resolution', 1, True)]
 
     # alias for the property
@@ -38,13 +36,3 @@ class FreqDomainSignal(SignalContainer):
         self._resolution_setter_(val)
 
 
-if __name__ == '__main__':
-    data1 = FreqDomainSignal(np.random.rand(12) + 1j * np.random.rand(12), f_resolution=10, unit='mV',
-                             description="Frequency response")
-    data2 = FreqDomainSignal(np.arange(12).reshape(1, -1), unit='V', description="H")
-
-    data2.reshape(-1).display()
-    data1.display()
-    data1.display(complex_plot='bode', db_scale=True)
-    data1.display(complex_plot='nyquist')
-
